@@ -1,4 +1,6 @@
 /**
+ * SPDX-FileCopyrightText: 2016-2021 The Apache Software Foundation
+ * SPDX-License-Identifier: Apache-2.0
  * @license
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -19,5 +21,13 @@
  */
 
 module.exports = {
-  require: ['@babel/register', 'chai/register-assert'],
+  extension: ['.ts'],
+  ignore: ['node_modules'],
+  require: ['./babel-register.js', 'global-jsdom/register'],
+  timeout: 5000,
+  watchFiles: [
+    './test/**/*.ts',
+    './packages/*/src/**/*.ts',
+    './packages/*/test/**/*.ts',
+  ],
 };
