@@ -1,4 +1,6 @@
 /**
+ * SPDX-FileCopyrightText: 2016-2021 The Apache Software Foundation
+ * SPDX-License-Identifier: Apache-2.0
  * @license
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -20,8 +22,8 @@
 
 module.exports = {
   all: true,
-  include: ['packages/*/src/**/*.js'],
+  include: ['packages/*/src/**/*.ts'],
   instrument: false,
   sourceMap: false,
-  require: ['@babel/register'],
+  require: ['./babel-register.js'],
 };
